function do_all
% plot the eigenvalues of the propagator A fitted to the GFDL CM2,
% and the maximum amplification as function of the lead time tau:
close all; clear all;

runs_to_plot=[1:13];
%%runs_to_plot=[1:13 16];

% repeat twice, to plot everything for identity norm kernel and THC
% norm kernel:
for plot_number=1:2

  title_string=' ';
  if plot_number==1;name_ext='';else;name_ext='_X_THC';end

  irun=1;
  Nruns=length(runs_to_plot);
  while irun<=Nruns &&...
	      exist(sprintf('Output/run%2.2d/Figures',runs_to_plot(irun)),'dir')
irun
    legend_string(irun,:)=sprintf('%2d',runs_to_plot(irun));
    %title_string=[title_string,sprintf('%d: %s; ',runs_to_plot(irun),mycolors(irun))];

    % get d, max_amplif:
    load(sprintf('Output/run%2.2d/max_amplif%s.mat',runs_to_plot(irun),name_ext));
    [real_d,I]=sort(real(d),1,'descend');
    d=d(I);
    imag_d=sort(abs(imag(d)),1,'descend');

    figure(1)
    subplot(2,1,1);
    plot(real_d,[mycolors(irun) 'x']);
    h(1)=xlabel('n');
    h(2)=title(['real eigenvalues of A;' title_string]);
    h(3)=gca;
    set(h,'fontname','helvetica','fontsize',14,'fontweight','bold');
    hold on;
    
    subplot(2,1,2);
    plot(imag_d,[mycolors(irun) '+']);
    h(1)=xlabel('n');
    h(2)=title(['imag eigenvalues of A;' title_string]);
    h(3)=gca;
    set(h,'fontname','helvetica','fontsize',14,'fontweight','bold');
    hold on;
    
    figure(2)
    if max(abs(imag(max_amplif))) > 1.e-6;
      disp(' *** complex max_amplif!!'),runs_to_plot(irun)
      quit
    end
    if irun==1; axes('position',[0.2 0.2 0.6 0.6]); end; %[left, bottom, width, height]
    h(1)=plot(real(max_amplif),[mycolors(irun) mylinetype(irun)]);
    set(h(1),'LineWidth',1.5);
    h(2)=xlabel('\tau');
    h(3)=ylabel('\lambda');
    if plot_number==1; which_amplif=' T, S';
    else; which_amplif=' THC '; end
    h(4)=title(['max amplification' which_amplif]);
    h(5)=gca;
    [LEGH,OBJH,OUTH,OUTM] = legend(legend_string(1:irun,:));
    set(h(2:3),'fontname','helvetica','fontsize',16,'fontweight','bold');
    set(h(4:5),'fontname','helvetica','fontsize',12); % ,'fontweight','bold');
    set(OBJH(1:irun),'fontname','helvetica','fontsize',10); % ,'fontweight','normal');
    hold on;
    
    figure(3)
    plot(real(d),imag(d),[mycolors(irun) 'x']);
    h(1)=xlabel('real (eigenvalue)');
    h(2)=ylabel('imag (eigenvalue)');
    h(3)=title(['eigenvalues;' title_string]);
    h(4)=gca;
    set(h,'fontname','helvetica','fontsize',14,'fontweight','bold');
    hold on;
    % plot the unit circle, to see if any of the eigenvalues is
    % larger than one in absolute value:
    ii=0; r=1;
    for theta=0:0.01:2*pi+0.1
      ii=ii+1;
      x(ii)=r*cos(theta); y(ii)=r*sin(theta);
    end
    plot(x,y,'r-')
    
    irun=irun+1;
  end

  figure(1)
  saveas(gcf,['Output/eigenvals_all_runs' name_ext '.fig']);
  print(gcf,'-depsc',['Output/eigenvals_all_runs' name_ext '.eps']);
  
  figure(2)
  saveas(gcf,['Output/max_amplif_all_runs' name_ext '.fig']);
  print(gcf,'-depsc',['Output/max_amplif_all_runs' name_ext '.eps']);
  
  figure(3)
  saveas(gcf,['Output/real_vs_imag_eigenvalues_all_runs' name_ext '.fig']);
  print(gcf,'-depsc',['Output/real_vs_imag_eigenvalues_all_runs' name_ext '.eps']);

  close all; clear h
end


function clr=mycolors(ii);

colors1=[ 'r';'g';'b';'c';'m'...
	  ;'r';'g';'b';'c';'m'];
colors2=['r';'g';'b';'c';'m'];

if ii<=10
  clr=colors1(ii,:);
else
  clr=colors2(ii-10,:);
end


function clr=mylinetype(ii);

colors1=[ '-';'-';'-';'-';'-'...
	  ;':';':';':';':';':'];
colors2=['--';'--';'--';'--';'--'];

if ii<=10
  clr=colors1(ii,:);
else
  clr=colors2(ii-10,:);
end
